# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_aptos_api import schemas  # noqa: F401


class EstimateGasPriceResult(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "deprioritized_gas_estimate",
            "gas_estimate",
            "prioritized_gas_estimate",
        }
        
        class properties:
            deprioritized_gas_estimate = schemas.NumberSchema
            gas_estimate = schemas.NumberSchema
            prioritized_gas_estimate = schemas.NumberSchema
            __annotations__ = {
                "deprioritized_gas_estimate": deprioritized_gas_estimate,
                "gas_estimate": gas_estimate,
                "prioritized_gas_estimate": prioritized_gas_estimate,
            }
    
    deprioritized_gas_estimate: MetaOapg.properties.deprioritized_gas_estimate
    gas_estimate: MetaOapg.properties.gas_estimate
    prioritized_gas_estimate: MetaOapg.properties.prioritized_gas_estimate
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["deprioritized_gas_estimate"]) -> MetaOapg.properties.deprioritized_gas_estimate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["gas_estimate"]) -> MetaOapg.properties.gas_estimate: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["prioritized_gas_estimate"]) -> MetaOapg.properties.prioritized_gas_estimate: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["deprioritized_gas_estimate", "gas_estimate", "prioritized_gas_estimate", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["deprioritized_gas_estimate"]) -> MetaOapg.properties.deprioritized_gas_estimate: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["gas_estimate"]) -> MetaOapg.properties.gas_estimate: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["prioritized_gas_estimate"]) -> MetaOapg.properties.prioritized_gas_estimate: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["deprioritized_gas_estimate", "gas_estimate", "prioritized_gas_estimate", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        deprioritized_gas_estimate: typing.Union[MetaOapg.properties.deprioritized_gas_estimate, decimal.Decimal, int, float, ],
        gas_estimate: typing.Union[MetaOapg.properties.gas_estimate, decimal.Decimal, int, float, ],
        prioritized_gas_estimate: typing.Union[MetaOapg.properties.prioritized_gas_estimate, decimal.Decimal, int, float, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'EstimateGasPriceResult':
        return super().__new__(
            cls,
            *args,
            deprioritized_gas_estimate=deprioritized_gas_estimate,
            gas_estimate=gas_estimate,
            prioritized_gas_estimate=prioritized_gas_estimate,
            _configuration=_configuration,
            **kwargs,
        )
