# coding: utf-8

"""
    aptos-api

    The aptos-api provider  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from openapi_aptos_api.paths.blocks_block_height.get import GetBlockByHeight
from openapi_aptos_api.paths.blocks_by_version_version.get import GetBlockByVersion


class BlocksApi(
    GetBlockByHeight,
    GetBlockByVersion,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
